@@ -10,7 +10,7 @@ loss.grpreg <- function(y, yhat, family) {
       if (sum(y==1)) val[y==1,] <- -2*log(yhat[y==1, , drop=FALSE])
       if (sum(y==0)) val[y==0,] <- -2*log(1-yhat[y==0, , drop=FALSE])
     } else {
-      val <- numeric(length(y))
+      val <- double(length(y))
       if (sum(y==1)) val[y==1] <- -2*log(yhat[y==1])
       if (sum(y==0)) val[y==0] <- -2*log(1-yhat[y==0])
     }
@@ -23,17 +23,17 @@ loss.grpreg <- function(y, yhat, family) {
 }
 loss.grpsurv <- function(y, eta, total=TRUE) {
   ind <- order(y[,1])
-  d <- as.numeric(y[ind,2])
+  d <- as.integer(y[ind,2])
   if (is.matrix(eta)) {
     eta <- eta[ind, , drop=FALSE]
     r <- apply(eta, 2, function(x) rev(cumsum(rev(exp(x)))))
   } else {
-    eta <- eta[ind]
-    r <- rev(cumsum(rev(exp(eta))))
+    eta <- as.matrix(eta[ind])
+    r <- as.matrix(rev(cumsum(rev(exp(eta)))))
   }
   if (total) {
     return(-2*(crossprod(d, eta) - crossprod(d, log(r))))
   } else {
-    return(-2*(eta[d==1,] - log(r)[d==1,]))
+    return(-2*(eta[d==1, , drop=FALSE] - log(r)[d==1, , drop=FALSE]))
   }
 }
